package;

import openfl.display.Sprite;
using hx.strings.Strings;

class Main extends Sprite
{
  public function new()
  {
    super();
    // Strings are extended:
    "".isEmpty();      // returns true
    "   ".isBlank();   // returns true
    "123".isDigits();  // returns true
    "a".repeat(3);     // returns "aaa"
    "abc".reverse();   // returns "cba"

    // Int's are extended too:
    32.toChar().isSpace();       // returns true
    32.toChar().toString();      // returns " "
    32.toChar().isAscii();       // returns true
    6000.toChar().isAscii();     // returns false
    6000.toChar().isUTF8();      // returns true
    74.toHex();                  // returns "4A"

    // all functions are null-safe:
    var nullString:String = null;
    nullString.isWhitespace();    // returns false
    nullString.length8();         // returns 0
    nullString.contains("cat");   // returns false

    // all methods support UTF-8 on all platforms:
    "кот".toUpperCase8();         // returns "КОТ"
    "кот".toUpperCaseFirstChar(); // returns "Кот"
    "はいはい".length8();          // returns 4

    // ANSI escape sequence processing:
    "\x1B[1;33mHello World!\x1B[0m".ansiToHtml();            // returns '<span style="color:yellow;font-weight:bold;">Hello World!</span>'
    "\x1B[1;33mHello World!\x1B[0m".ansiToHtml(CssClasses);  // returns '<span class="ansi_fg_yellow ansi_bold">Hello World!</span>'
    "\x1B[1mHello World!\x1B[0m".removeAnsi();               // returns "Hello World!"

    // It is also possible to fully customize the css class names used using a callback:
    "\x1B[1;33mHello World!\x1B[0m".ansiToHtml(CallbackToCssClasses(function(st:hx.strings.ANSIState):String {
      var a : Array<String> = [];
      if (st.fgcolor != null) a.push("someprefix_fg_" + st.fgcolor + "_somesuffix");
      if (st.bgcolor != null) a.push("someprefix_bg_" + st.fgcolor);
      if (st.bold)            a.push("someprefix_bold");
      if (st.underline)       a.push("someprefix_underline");
      if (st.blink)           a.push("someprefix_blink");
      return a.join(" ");
    }));  // returns '<span class="ansi_fg_yellow ansi_bold">Hello World!</span>'

    // case formatting:
    "look at me".toUpperCamel();       // returns "LookAtMe"
    "MyCSSClass".toLowerCamel();       // returns "myCSSClass"
    "MyCSSClass".toLowerHyphen();      // returns "my-css-class"
    "MyCSSClass".toLowerUnderscore();  // returns "my_css_class"
    "myCSSClass".toUpperUnderscore();  // returns "MY_CSS_CLASS"

    // ellipsizing strings:
    "The weather is very nice".ellipsizeLeft(20);    // returns "The weather is ve..."
    "The weather is very nice".ellipsizeMiddle(20);  // returns "The weath...ery nice"
    "The weather is very nice".ellipsizeRight(20);   // returns "...ther is very nice"

    // string differences:
    "It's green".diffAt("It's red"); // returns 5
    "It's green".diff("It's red");   // returns { left: 'green', right: 'red', at: 5 }

  // hash codes:
  "Cool String".hashCode();       // generate a platform specific hash code
  "Cool String".hashCode(CRC32B);  // generate a hash code using CRC32
  "Cool String".hashCode(JAVA);   // generate a hash code using the Java hash algorithm

  // cleanup:
  "/my/path/".removeLeading("/");       // returns "my/path/"
  "/my/path/".removeTrailing("/");      // returns "/my/path"
  "<i>So</i> <b>nice</b>".removeTags(); // returns "So nice"
  }
}
